@@ -1,25 +1,12 @@
 /*
-    Copyright (C) 2010 Casey Link <unnamedrambler@gmail.com>
-    Copyright (C) 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+    SPDX-FileCopyrightText: 2010 Casey Link <unnamedrambler@gmail.com>
+    SPDX-FileCopyrightText: 2009-2010 Klaralvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
 
     Refactored from earlier code by:
-    Copyright (c) 2010 Volker Krause <vkrause@kde.org>
-    Copyright (c) 2004 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2010 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2004 Cornelius Schumacher <schumacher@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef MULTIPLYINGLINEEDITOR_H
@@ -89,14 +76,14 @@ public:
     // We take ownership of factory
     explicit MultiplyingLineEditor(MultiplyingLineFactory *factory, QWidget *parent = nullptr);
 
-    virtual ~MultiplyingLineEditor();
+    ~MultiplyingLineEditor() override;
 
     /** Get the current line factory for this instance of the widget.
      */
     MultiplyingLineFactory *factory() const;
 
     /** Retrieve the data from the editor */
-    QList<MultiplyingLineData::Ptr> allData() const;
+    QVector<MultiplyingLineData::Ptr> allData() const;
 
     /** Retrieve the data of the active line */
     MultiplyingLineData::Ptr activeData() const;
@@ -177,11 +164,11 @@ public Q_SLOTS:
 
 protected:
     virtual MultiplyingLine *activeLine() const;
-    bool mModified;
+    bool mModified = false;
 
 private:
-    MultiplyingLineFactory *mMultiplyingLineFactory;
-    MultiplyingLineView *mView;
+    MultiplyingLineFactory *const mMultiplyingLineFactory;
+    MultiplyingLineView *mView = nullptr;
 };
 }
 #endif // MULTIPLYINGLINEEDITOR_H
